@@ -223,7 +223,6 @@ class SoftwarecenterDbusService(dbus.service.Object):
         print "####del_worker_item_by_name finished!"
 
     def check_cancel_worker_item(self, cancelinfo):
-#        print "####check_cancel_worker_item:",pkgname
         cancel = False
         self.cancelmutex.acquire()
 #        print "check_cancel_worker_item:",len(self.cancel_name_list)
@@ -439,13 +438,13 @@ class SoftwarecenterDbusService(dbus.service.Object):
         return "True"
     #????????????????????????????
     # apt-get update sa:software_fetch_signal()
-    @dbus.service.method(INTERFACE, in_signature='b', out_signature='b', sender_keyword='sender')
+    @dbus.service.method(INTERFACE, in_signature='b', out_signature='s', sender_keyword='sender')
     def update_first(self, quiet, sender=None):
         print "####update first: "
 
         granted = self.auth_with_policykit(sender,UBUNTUKYLIN_SOFTWARECENTER_ACTION,"要更新软件源")
         if not granted:
-            return False
+            return "False"
 
         kwargs = {"quiet":str(quiet),
                   }
@@ -456,7 +455,7 @@ class SoftwarecenterDbusService(dbus.service.Object):
 
 #        self.daemonApt.update()
 
-        print "####update return"
+        return "True"
 
     # check packages status by pkgNameList sa:software_check_status_signal()
     @dbus.service.method(INTERFACE, in_signature='as', out_signature='')
@@ -616,7 +615,14 @@ class SoftwarecenterDbusService(dbus.service.Object):
     @dbus.service.method(INTERFACE, in_signature='', out_signature='')
     def set_uksc_not_working(self):
         self.worker_thread.uksc_is_working = 0
-    
+
+    @dbus.service.method(INTERFACE, in_signature='', out_signature='')
+    def exit(self):
+        self.mainloop.quit()
+
+    @dbus.service.method(INTERFACE, in_signature='', out_signature='')
+    def check_dpkg_statu(self):
+        os.system("dpkg --configure -a")
 
 if __name__ == '__main__':
     os.environ["TERM"] = "xterm"
