@@ -44,6 +44,8 @@ from backend.reviewratingspawn import SpawnProcess, RatingSortMethods,ReviewRati
 from backend.service.dbmanager import Database
 from utils.silentprocess import *
 from utils.machine import *
+from utils.debfile import DebFile
+from models.globals import Globals
 from models.enums import (UBUNTUKYLIN_SERVER, UBUNTUKYLIN_RES_PATH, UBUNTUKYLIN_DATA_CAT_PATH, UBUNTUKYLIN_RES_SCREENSHOT_PATH)
 from models.enums import Signals,UnicodeToAscii
 
@@ -81,11 +83,17 @@ class ThreadWorkerDaemon(threading.Thread):
 
             reslist = []
             if item.funcname == "update_models":
-                self.appmgr._update_models()
+                self.appmgr._update_models(item.kwargs)
             elif item.funcname == "init_models":
-                self.appmgr._init_models()
+                try:
+                    self.appmgr._init_models()
+                except Exception as e:
+                    print "ThreadWorkerDaemon error", e.message
             elif item.funcname == "get_reviews":
-                reslist = self.appmgr.db.get_review_by_pkgname(item.kwargs['packagename'],item.kwargs['page'])
+                try: #if no network the thread will be crashed, so add try except
+                    reslist = self.appmgr.db.get_review_by_pkgname(item.kwargs['packagename'],item.kwargs['page'])
+                except Exception as e:
+                    print "ThreadWorkerDaemon error", e.message
             # elif item.funcname == "get_images":
             #     pass
             else:
@@ -99,7 +107,7 @@ class ThreadWorkerDaemon(threading.Thread):
                 resLen = queue.qsize()
                 while resLen:
                     try:
-                        count  = 0
+                        count = 0
 #                        print "@@@@@@@@@:",queue.qsize(),item
                         while queue.qsize():
              #               print "@@enter while"
@@ -111,7 +119,7 @@ class ThreadWorkerDaemon(threading.Thread):
                         #queue.close()
                     except Queue.Empty:
 #                        print "&&&&&&&&&&get error:",queue.qsize()
-                        count  += 1
+                        count += 1
 
                     resLen = queue.qsize()
                 print "receive data from backend process, func, qlen, len=",item.funcname,queue.qsize(),len(reslist)
@@ -136,18 +144,18 @@ class AppManager(QObject):
         self.distroseries = 'any'  #'any' for all
         self.db = Database()
 
-        self.worklist = []
-        self.mutex = threading.RLock()
-        self.worker_thread = ThreadWorkerDaemon(self)
-        self.worker_thread.setDaemon(True)
-        self.worker_thread.start()
-
         # silent process work queue
         self.squeue = multiprocessing.Queue()
         self.silent_process = SilentProcess(self.squeue)
         self.silent_process.daemon = True
         self.silent_process.start()
 
+        self.worklist = []
+        self.mutex = threading.RLock()
+        self.worker_thread = ThreadWorkerDaemon(self)
+        self.worker_thread.setDaemon(True)
+        self.worker_thread.start()
+
         self.premoter = PistonRemoter(service_root=UBUNTUKYLIN_SERVER)
 
     # re new piston remoter auth by current login token
@@ -157,13 +165,11 @@ class AppManager(QObject):
 
     def check_source_update(self):
         f = QFile("/var/lib/apt/periodic/update-success-stamp")
-        if(f.exists() == False):
-            return True
+        if(f.exists() == True):
+            return False
         else:
-            # fi = QFileInfo(f)
-            # dt = fi.lastModified()
-            # return dt.toString("yyyyMMddhh")
-            # return True
+            if self.sourcelist_need_update():
+                return True
             return False
 
     #open the apt cache and get the package count
@@ -179,28 +185,31 @@ class AppManager(QObject):
         self.cat_list = self.get_category_list_from_db()
 
     def init_models(self):
-        item  = WorkerItem("init_models",None)
+        item = WorkerItem("init_models",None)
         self.mutex.acquire()
         self.worklist.append(item)
         self.mutex.release()
 
-    def _update_models(self):
+    def _update_models(self,kwargs):
         self.open_cache()
-
         for cname,citem in self.cat_list.iteritems():
             apps = citem.apps
             for aname,app in apps.iteritems():
                 app.update_cache(self.apt_cache)
+        if "update" == kwargs["action"]:
+            self.emit(Signals.count_application_update)
+        self.emit(Signals.refresh_page)
 
-    def update_models(self,action,pkgname=""):
+    def update_models(self,action, pkgname=""):
         kwargs = {"packagename": pkgname,
                   "action": action,
                   }
-
-        item  = WorkerItem("update_models",kwargs)
+        item = WorkerItem("update_models",kwargs)
         self.mutex.acquire()
         self.worklist.append(item)
         self.mutex.release()
+        if "install_debfile" == action:
+            self.update_xapiandb(pkgname)
 
     def get_category_list_from_db(self):
         list = self.db.query_categories()
@@ -239,11 +248,10 @@ class AppManager(QObject):
             else:
                 app = Application(pkgname,displayname_cn, cat, self.apt_cache)
                 if app.package and app.package.candidate:
-                    apps[pkgname] = app
-                    Globals.ALL_APPS[pkgname] = app #make sure there is only one app with the same pkgname even it may belongs to other category
                     #if there has special information in db, get them
                     #get_category_apps_from_db: 0 0
                     #display_name, summary, description, rating_average,rating_total,review_total,download_total
+                    app.from_ukscdb = True
                     app.orig_name = app.name#zx2015.01.26
                     app.orig_summary = app.summary
                     app.orig_description = app.description
@@ -271,6 +279,8 @@ class AppManager(QObject):
                         app.review_total = int(review_total)
                         # if rank is not None:
                         #     app.rank = int(rank)
+                    apps[pkgname] = app
+                    Globals.ALL_APPS[pkgname] = app #make sure there is only one app with the same pkgname even it may belongs to other category
         return apps
 
     def download_category_apps(self,cat,catdir=""):
@@ -322,11 +332,27 @@ class AppManager(QObject):
         if self.cat_list is None:
             return None
         #
-        for (catname, cat) in self.cat_list.iteritems():
+        for (catname, cat) in self.cat_list.iteritems(): #get app in cat which init in uksc startup
             app = cat.get_application_byname(pkgname)
-            if app is not None:
+            if app is not None and app.package is not None:
                 return app
 
+        pkg = self.get_package_by_name(pkgname)
+        if pkg is not None and pkg.candidate is not None: #get app from cache and add it to cat  when app not in cat
+            displayname_cn = pkgname
+            app = Application(pkgname, displayname_cn, cat, self.apt_cache)
+            app.orig_name = app.name
+            app.orig_summary = app.summary
+            app.orig_description = app.description
+            app.displayname = app.name
+            app.summary = app.summary
+            app.description = app.description
+            app.from_ukscdb = False
+
+            cat = self.cat_list["Accessories"]
+            cat.apps[pkgname] = app
+            return app
+
         return None
 
     #get package object by appname
@@ -343,13 +369,16 @@ class AppManager(QObject):
             package = self.apt_cache[pkgname]
         except:
             package = None
+        else:
+            if package.candidate is None:
+                package = None
 
         return package
 
     def get_application_count(self,cat_name=""):
         sum_inst = 0
         sum_up = 0
-        sum_all = 0
+        sum_all = len(self.apt_cache)
 
         if len(cat_name)>0:
             cat = self.cat_list[cat_name]
@@ -362,7 +391,6 @@ class AppManager(QObject):
                 if package is None:
                     continue
 
-                sum_all = sum_all + 1
                 if package.is_installed:
                     sum_inst = sum_inst + 1
                 if package.is_upgradable:
@@ -387,7 +415,7 @@ class AppManager(QObject):
         return rnrStat
 
     #get advertisements, this is now implemented locally
-    def get_advertisements(self):
+    def get_advertisements(self, bysignal=False):
         print "we need to get the advertisements"
         tmpads = []
         tmpads.append(Advertisement("pchomewallpaper", "url", "ad0.png", "adbground0.png", "http://download.pchome.net/wallpaper/"))
@@ -396,13 +424,18 @@ class AppManager(QObject):
         tmpads.append(Advertisement("dota2", "url", "ad3.png", "adbground3.png", "http://www.ubuntukylin.com/ukylin/forum.php?mod=viewthread&tid=7687&extra=page%3D1"))
         tmpads.append(Advertisement("pps", "url", "ad4.png", "adbground4.png", "http://dl.pps.tv/pps_linux_download.html"))
         tmpads.append(Advertisement("pchomewallpaper", "url", "ad5.png", "adbground5.png", "http://download.pchome.net/wallpaper/"))
-        self.emit(Signals.ads_ready,tmpads)
+        self.emit(Signals.ads_ready, tmpads, bysignal)
 
     #get apps in ubuntukylin archives, this is now implemented with config file
     #then we can sync with the archive
     def get_ubuntukylin_apps(self):
         print "we need to get the applications by condition recommend"
-        return self.get_category_apps("ubuntukylin")
+        apps = self.get_category_apps("ubuntukylin")
+        for(pkgname, app) in apps:
+            if app is None or app.package is None:
+                del apps[pkgname]
+        return apps
+
 
     #get rating and review status
     def get_rating_review_stats(self,callback=None):
@@ -425,7 +458,7 @@ class AppManager(QObject):
         item = WorkerItem("get_reviews",kwargs)
 
         app = self.get_application_by_name(pkgname)
-        if app is not None:
+        if app is not None and app.package is not None:
             reviews = app.get_reviews(page)
 
         # force == True means need get review from server immediately
@@ -442,7 +475,7 @@ class AppManager(QObject):
     def get_application_screenshots(self,pkgname, cachedir=UBUNTUKYLIN_RES_SCREENSHOT_PATH, callback=None):
         LOG.debug("request to get screenshots:%s",pkgname)
         app = self.get_application_by_name(pkgname)
-        if app is None:
+        if app is None or app.package is None:
             return False
 
         kwargs = {"packagename": pkgname,
@@ -474,7 +507,7 @@ class AppManager(QObject):
             page = item.kwargs['page']
 
             app = self.get_application_by_name(item.kwargs['packagename'])
-            if app is not None:
+            if app is not None and app.package is not None:
                 app.add_reviews(page,reviews)
             else:
                 print item.kwargs['packagename'], " not exist"
@@ -484,7 +517,7 @@ class AppManager(QObject):
             LOG.debug("screenshots ready:%s",len(reslist))
             screenshots = reslist
             app = self.get_application_by_name(item.kwargs['packagename'])
-            if app is not None:
+            if app is not None and app.package is not None:
                 app.screenshots = screenshots
             else:
                 print item.kwargs['packagename'], " not exist"
@@ -498,7 +531,7 @@ class AppManager(QObject):
 
             for rnrStat in rnrStats:
                 app = self.get_application_by_name(str(rnrStat.pkgname))
-                if app is not None:
+                if app is not None and app.package is not None:
                     app.ratings_average = rnrStat.ratings_average
                     app.ratings_total = rnrStat.ratings_total
                 if(str(rnrStat.pkgname) == "gparted"):
@@ -577,9 +610,8 @@ class AppManager(QObject):
         self.squeue.put_nowait(item)
 
     # update xapiandb add by zhangxin
-    def update_xapiandb(self):
-        kwargs = {}
-        
+    def update_xapiandb(self, pkgname):
+        kwargs = {"pkgname": pkgname, "path": Globals.LOCAL_DEB_FILE}
         item = SilentWorkerItem("update_xapiandb", kwargs)
         self.squeue.put_nowait(item)
 
@@ -590,7 +622,7 @@ class AppManager(QObject):
         self.squeue.put_nowait(item)
         
     # get recommend apps
-    def get_recommend_apps(self):
+    def get_recommend_apps(self, bysignal=False):
         recommends = self.db.get_recommend_apps()
         applist = []
         for rec in recommends:
@@ -599,7 +631,7 @@ class AppManager(QObject):
                 app.recommendrank = rec[1]
                 applist.append(app)
 
-        self.emit(Signals.recommend_ready,applist)
+        self.emit(Signals.recommend_ready, applist, bysignal)
 
     # get pointout apps
     def get_pointout_apps(self):
@@ -625,26 +657,27 @@ class AppManager(QObject):
         self.db.set_pointout_is_show(flag)
 
     # get rating rank apps
-    def get_ratingrank_apps(self):
+    def get_ratingrank_apps(self, bysignal=False):
         ratingranks = self.db.get_ratingrank_apps()
         applist = []
         for rr in ratingranks:
             app = self.get_application_by_name(rr[0])
-            if(app is not None):
+            if(app is not None and app.package is not None):
                 app.ratingrank = rr[1]
                 try:
                     applist.index(app)
                 except:
                     applist.append(app)
 
-        self.emit(Signals.ratingrank_ready,applist)
+        self.emit(Signals.ratingrank_ready, applist, bysignal)
 
     def submit_review(self, app_name, content):
         distroseries = get_distro_info()[2]
         language = get_language()
-
-        res = self.premoterauth.submit_review(app_name, content, distroseries, language, Globals.USER, Globals.USER_DISPLAY)
-
+        try:
+            res = self.premoterauth.submit_review(app_name, content, distroseries, language, Globals.USER, Globals.USER_DISPLAY)
+        except:
+            res = "False"
         self.emit(Signals.submit_review_over, res)
 
     def submit_translate_appinfo(self, appname,type_appname, type_summary, type_description, orig_appname, orig_summary, orig_description, trans_appname, trans_summary, trans_description):
@@ -653,13 +686,15 @@ class AppManager(QObject):
         try:
             res = self.premoterauth.submit_translate_appinfo(appname,type_appname, type_summary, type_description, orig_appname, orig_summary, orig_description, trans_appname, trans_summary, trans_description, Globals.USER, Globals.USER_DISPLAY)
         except:
-             res = "网络出错"
+             res = "False"
         self.emit(Signals.submit_translate_appinfo_over, res)
 
 
     def submit_rating(self, app_name, rating):
-        res = self.premoterauth.submit_rating(app_name, rating, Globals.USER, Globals.USER_DISPLAY)
-
+        try:
+            res = self.premoterauth.submit_rating(app_name, rating, Globals.USER, Globals.USER_DISPLAY)
+        except:
+            res = False
         self.emit(Signals.submit_rating_over, res)
 
     # update app ratingavg in cache db after user do rating app
@@ -670,14 +705,14 @@ class AppManager(QObject):
         try:
             res = self.premoter.get_user_applist(Globals.USER)
         except:
-            res = "False"
+            res = False
         self.emit(Signals.get_user_applist_over, res)
 
     def get_user_transapplist(self):#zx 2015.01.30
         try:
             res = self.premoter.get_user_transapplist(Globals.USER)
         except:
-            res = "False"
+            res = False
         self.emit(Signals.get_user_transapplist_over, res)
 
 
@@ -691,6 +726,16 @@ class AppManager(QObject):
     def update_exists_data(self, exists, id):
         self.db.update_exists_data(exists, id)
 
+    def sourcelist_need_update(self):
+        res = self.db.need_do_sourcelist_update()
+        if('True' == res):
+            return True
+        else:
+            return False
+
+    def set_check_update_false(self):
+        self.db.set_update_sourcelist_false()
+
 
 def _reviews_ready_callback(str_pkgname, reviews_data, my_votes=None,
                         action=None, single_review=None):
