@@ -45,7 +45,6 @@ from utils import commontools
 from utils.debfile import DebFile
 from models.globals import Globals
 
-
 class DetailScrollWidget(QScrollArea):
     mainwindow = ''
     app = None
@@ -276,7 +275,7 @@ class DetailScrollWidget(QScrollArea):
 
     def show_by_local_debfile(self, path):
         # clear reviews
-        Globals.NOWPAGE = PageStates.ALLPAGE
+        self.btns.loading.stop_loading()
         self.reviewpage = 1
         self.currentreviewready = False
         self.ui.reviewListWidget.clear()
@@ -332,15 +331,19 @@ class DetailScrollWidget(QScrollArea):
             self.ui.size.setText("安装大小: " + str('%.2f'%(sizek/1024.0)) + " MB")
         self.ui.description.setText(self.debfile.description)
 
-        if(self.debfile.is_installable()):
-            deps = self.debfile.get_missing_deps()
-            if (deps == []):
-                deps = ""
-            self.ui.summary.setText("需要安装的依赖包: " + str(deps))
+        deps = self.debfile.get_missing_deps()
+        if (deps == []):
+            deps = ""
+        self.ui.summary.setText("需要安装的依赖包: " + str(deps))
+
+        if(self.debfile.is_installable):
             self.ui.status.hide()
             self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
             # self.ui.btnInstall.setText("安装此包")
             # self.ui.btnInstall.setEnabled(True)
+        elif 1 == self.debfile.debfile.compare_to_version_in_cache(True):
+            self.debfile.is_installable = True
+            self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
         else:
             print "it can not be installed......"
             self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
@@ -351,6 +354,17 @@ class DetailScrollWidget(QScrollArea):
         self.mainwindow.ui.detailShellWidget.show()
         self.mainwindow.loadingDiv.stop_loading()
 
+        # if 1 == self.debfile.debfile.compare_to_version_in_cache(True):
+        #     button = QMessageBox.warning(self,"版本冲突",
+        #                 self.tr("当前安装包的版本低于已安装版本\n确定要安装更低版本？\n\n请选择:"),
+        #                 "安装", "取消", "", 1, 1)
+        #     if 0 == button:
+        #         self.ui.status.hide()
+        #         self.debfile.is_installable = True
+        #         self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
+        #     else:
+        #         self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
+
     # fill fast property, show ui, request remote property
     def showSimple(self, app):
         # clear reviews
@@ -454,6 +468,7 @@ class DetailScrollWidget(QScrollArea):
         self.ui.transDescriptionStatus.setStyleSheet("QLabel{background-image:url('res/installed.png')}")
         self.ui.status.setStyleSheet("QLabel{background-image:url('res/installed.png')}")
 
+# Tow ways go to detailpage 1.from normalcard,recmmandcard,wincard,listitemwidget,they all have app.status 2.from transpage, homepage-rankitem,homepage-ad, then all don't have app.status
         if self.app.status == PkgStates.INSTALL:
             self.btns.stop_work()#zx 2015.01.23 for bug1402527
             self.ui.status.hide()
@@ -480,33 +495,44 @@ class DetailScrollWidget(QScrollArea):
             self.ui.status.show()
         else:
             # click the rank item or ad item on homepage
-            if(Globals.NOWPAGE == PageStates.HOMEPAGE):
+            if Globals.NOWPAGE == PageStates.HOMEPAGE:
+                self.btns.stop_work()
                 if app.pkg_status == PkgStates.INSTALLED:
-                    if(run.get_run_command(app.name) == ""):
+                    if run.get_run_command(app.name) == "":
+                        app.status = PkgStates.NORUN
                         self.btns.reset_btns(app, PkgStates.NORUN)
                     else:
+                        app.status = PkgStates.RUN
                         self.btns.reset_btns(app, PkgStates.RUN)
                     self.ui.status.show()
                 elif app.pkg_status == PkgStates.UNINSTALLED:
+                    app.status = PkgStates.INSTALL
                     self.btns.reset_btns(app, PkgStates.INSTALL)
                     self.ui.status.hide()
                 elif app.pkg_status == PkgStates.UPGRADABLE:
+                    app.status = PkgStates.UPDATE
                     self.btns.reset_btns(app, PkgStates.UPDATE)
                     self.ui.status.show()
-                print 'another status in detail page......'
-                print app.status
+            elif Globals.NOWPAGE == PageStates.TRANSPAGE:
+                self.btns.stop_work()
+                if app.is_installed is True:
+                    self.ui.status.show()
+                    if run.get_run_command(app.name) == "":
+                        app.status = PkgStates.NORUN
+                        self.btns.reset_btns(app, PkgStates.NORUN)
+                    else:
+                        app.status = PkgStates.RUN
+                        self.btns.reset_btns(app, PkgStates.RUN)
+                else:
+                    self.ui.status.hide()
+                    app.status = PkgStates.INSTALL
+                    self.btns.reset_btns(app, PkgStates.INSTALL)
+
+        if self.app.percent > 0:
+            self.btns.start_work()
 
         if Globals.NOWPAGE == PageStates.TRANSPAGE:
             self.ui.btn_change.setText("完善翻译")
-            self.ui.status.hide()
-            if app.is_installed is True:
-                if(run.get_run_command(app.name) == ""):
-                    self.btns.reset_btns(app, PkgStates.NORUN)
-                else:
-                    self.btns.reset_btns(app, PkgStates.RUN)
-            else:
-                self.btns.reset_btns(app, PkgStates.INSTALL)
-
             if hasattr(self.app,"transname"):
                 self.ui.name.setText(app.transname)
                 if self.app.transnamestatu is True:
@@ -736,7 +762,7 @@ class DetailScrollWidget(QScrollArea):
                 self.type_description = 'True'
             else:
                 self.type_description = 'False'
-                description = "<1_1"
+                description = "<1_1>"
 
             if(self.appname == self.init_name  and self.summary == self.init_summary  and  self.description == self.init_description):
                 self.mainwindow.messageBox.alert_msg("您未翻译或修改任何部分")
@@ -777,14 +803,19 @@ class DetailScrollWidget(QScrollArea):
             self.mainwindow.messageBox.alert_msg("翻译已提交")
         elif(res == 1):
             self.mainwindow.messageBox.alert_msg("提交过于频繁，请稍后再试")
-        elif(res == "网络出错"):
-            self.messageBox.alert_msg("网络连接出错\n"
+        elif 3 == res:
+            self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件进行翻译")
+        elif(res == "False"):
+            self.messageBox.alert_msg("连接服务器出错\n"
                                         "提交翻译失败")
         else:
             self.mainwindow.messageBox.alert_msg("翻译的字数过多\n"
                                                  "或其它未知错误")
 
     def slot_submit_review(self):
+        if self.app.from_ukscdb is not True:
+            self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件进行评论")
+            return
         if(Globals.USER != ''):
             content = str(self.ui.reviewText.toPlainText())
             if(content.strip() != ''):
@@ -817,10 +848,16 @@ class DetailScrollWidget(QScrollArea):
             self.mainwindow.messageBox.alert_msg("对本软件评论过于频繁")
         elif(res == 3):
             self.mainwindow.messageBox.alert_msg("对本软件评论次过多")
+        elif(res == 5):
+            self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件评论")
         else:
-            self.mainwindow.messageBox.alert_msg("未知错误")
+            self.mainwindow.messageBox.alert_msg("服务器连接失败")
 
     def slot_submit_rating(self, rating):
+        if self.app.from_ukscdb is not True:
+            self.messageBox.alert_msg("非数据库中软件\n暂不能对该软件评分")
+            print "ignore submit rating"
+            return
         if(Globals.USER != ''):
             self.submitratingload.start_loading()
             self.emit(Signals.submit_rating, self.app.name, rating)
@@ -874,7 +911,7 @@ class DetailScrollWidget(QScrollArea):
                     else:
                         self.app.status = PkgStates.RUN
                         self.btns.reset_btns(self.app, PkgStates.RUN)
-                    self.debfile = None
+                    # self.debfile = None
                 else:
                     if (Globals.NOWPAGE == PageStates.UNPAGE or Globals.NOWPAGE == PageStates.SEARCHUNPAGE):
                         self.app.status = PkgStates.UNINSTALL
@@ -900,19 +937,22 @@ class DetailScrollWidget(QScrollArea):
                     self.app.status = PkgStates.RUN
                     self.btns.reset_btns(self.app, PkgStates.RUN)
                 self.ui.status.show()
-        self.btns.stop_work()
+            self.btns.stop_work()
 
     def slot_work_cancel(self, pkgname, action):
         if self.app is None:
             return
 
         if self.app.name == pkgname:
-            if action == AppActions.INSTALL:
-                self.app.status = PkgStates.INSTALL
-                self.btns.reset_btns(self.app, PkgStates.INSTALL)#zx 2015.02.09
+            if action in (AppActions.INSTALL, AppActions.INSTALLDEBFILE):
+                if action == AppActions.INSTALL:
+                    self.app.status = PkgStates.INSTALL
+                    self.btns.reset_btns(self.app, PkgStates.INSTALL)#zx 2015.02.09
+                else:
+                    self.btns.reset_btns(self.app, PkgStates.INSTALL, self.debfile)
                 self.ui.status.hide()
-                if self.debfile:
-                    self.debfile = None
+                # if self.debfile:
+                #     self.debfile = None
 
             elif action == AppActions.REMOVE:
                 self.app.status = PkgStates.UNINSTALL
@@ -923,7 +963,12 @@ class DetailScrollWidget(QScrollArea):
                 self.app.status = PkgStates.UPDATE
                 self.btns.reset_btns(self.app, PkgStates.UPDATE)#zx 2015.02.09
                 self.ui.status.show()
-        self.btns.stop_work()
+            self.btns.stop_work()
+
+    def slot_proccess_change(self, pkgname, action):
+        if hasattr(self, "app") and self.app is not None:
+            if self.app.name == pkgname:
+                self.btns.start_work()
 
     def scrollToTop(self):#zx 2015.01.23 for bug1402930
         vsb = self.verticalScrollBar()
