@@ -329,4 +329,24 @@ class PointCard(QWidget):
                 else:
                     self.app.status = PkgStates.RUN
                     self.ui.btn.setText("启动")
-                    self.ui.btn.setEnabled(True)
\ No newline at end of file
+                    self.ui.btn.setEnabled(True)
+            elif action == AppActions.INSTALLDEBFILE:
+                if self.app.is_installed:
+                    if run.get_run_command(self.app.name) == "":
+                        self.app.status = PkgStates.NORUN
+                        self.ui.btn.setText("已安装")
+                        self.ui.btn.setEnabled(False)
+                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
+                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
+                    else:
+                        self.app.status = PkgStates.RUN
+                        self.ui.btn.setText("启动")
+                        self.ui.btn.setEnabled(True)
+                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
+                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
+                else:
+                    self.app.status = PkgStates.INSTALL
+                    self.ui.btn.setText("安装")
+                    self.ui.btn.setEnabled(True)
+                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
+                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
