@@ -145,8 +145,47 @@ class RcmdCard(QWidget):
 
         # add by kobe
         self.ui.isInstalled.setText("已安装")
+        if self.app.status in (PkgStates.INSTALLING, PkgStates.REMOVING, PkgStates.UPGRADING):
+            self.star.hide()
+            self.ui.progressBar.setVisible(True)
+            self.ui.progresslabel.setVisible(True)
+            self.ui.progressBar_icon.setVisible(True)
+            self.ui.progressBar.setValue(self.app.percent)
+            self.ui.progresslabel.setText(str('%.0f' % self.app.percent) + '%')
 
-        if(self.app.is_installed):
+        if self.app.status == PkgStates.INSTALLING:
+            self.ui.btn.setEnabled(False)
+            if self.app.percent > 0:
+                self.ui.btn.setText("正在安装")
+            else:
+                self.ui.btn.setText("等待安装")
+            self.ui.progressBar.setStyleSheet("QProgressBar{background-color:#F4F8FB;border:0px;border-radius:0px;color:#1E66A4;}"
+                                              "QProgressBar:chunk{background-color:#BBF9A3;}")
+            self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
+            self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
+        elif self.app.status == PkgStates.REMOVING:
+            self.ui.btn.setEnabled(False)
+            if self.app.percent > 0:
+                self.ui.btn.setText("正在卸载")
+            else:
+                self.ui.btn.setText("等待卸载")
+            self.ui.progressBar.setStyleSheet("QProgressBar{background-color:#F4F8FB;border:0px;border-radius:0px;color:#1E66A4;}"
+                                            "QProgressBar:chunk{background-color:#C5CED9;}")
+            self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
+            self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
+
+        elif self.app.status == PkgStates.UPGRADING:
+            self.ui.btn.setEnabled(False)
+            if self.app.percent > 0:
+                self.ui.btn.setText("正在升级")
+            else:
+                self.ui.btn.setText("等待升级")
+            self.ui.progressBar.setStyleSheet("QProgressBar{background-color:#F4F8FB;border:0px;border-radius:0px;color:#1E66A4;}"
+                                              "QProgressBar:chunk{background-color:#FDD99A;}")
+            self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-up-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-up-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-up-btn-3.png');}")
+            self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-up-border.png');}")
+
+        elif(self.app.is_installed):
             # add by kobe
             self.star.hide()
             self.ui.isInstalled.setVisible(True)
@@ -392,27 +431,50 @@ class RcmdCard(QWidget):
                 self.ui.btn.setEnabled(True)
                 self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
                 self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
-            elif action == AppActions.REMOVE:#can not appear on home page
-                self.app.status = PkgStates.UNINSTALL
+            elif action in (AppActions.REMOVE, AppActions.UPGRADE):
                 self.star.hide()
                 self.ui.isInstalled.setVisible(True)
                 if(run.get_run_command(self.app.name) == ""):
+                    self.app.status = PkgStates.NORUN
                     self.ui.btn.setText("已安装")
                     self.ui.btn.setEnabled(False)
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
                 else:
                     self.ui.btn.setText("启动")
+                    self.app.status = PkgStates.RUN
                     self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
                     self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
-            elif action == AppActions.UPGRADE:
-                self.app.status = PkgStates.UPDATE
-                self.star.hide()
-                self.ui.isInstalled.setVisible(True)
-                self.ui.btn.setText("升级")
-                self.ui.btn.setEnabled(True)
-                self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-up-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-up-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-up-btn-3.png');}")
-                self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-up-border.png');}")
 
-            if self.app.percent < 0:
-                self.star.hide()
\ No newline at end of file
+            elif action == AppActions.INSTALLDEBFILE:
+                if(self.app.is_installed):
+                    self.star.hide()
+                    self.ui.isInstalled.setVisible(True)
+
+                    if(run.get_run_command(self.app.name) == ""):
+                        self.app.status = PkgStates.NORUN
+                        self.ui.btn.setText("已安装")
+                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-un-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-un-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-un-btn-3.png');}")
+                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-un-border.png');}")
+                        self.ui.btn.setEnabled(False)
+                    else:
+                        self.app.status = PkgStates.RUN
+                        self.ui.btn.setText("启动")
+                        self.ui.btn.setEnabled(True)
+                        self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-run-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-run-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-run-btn-3.png');}")
+                        self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-run-border.png');}")
+                else:
+                    # star = StarWidget("small", self.app.ratings_average, self.ui.baseWidget)
+                    # star.move(75, 56)
+                    # init app.status
+                    self.app.status = PkgStates.INSTALL
+                    self.star.show()
+                    self.ui.isInstalled.setVisible(False)
+                    self.ui.btn.setText("安装")
+                    self.ui.btn.setEnabled(True)
+                    self.ui.btn.setStyleSheet("QPushButton{color:white;border:0px;background-image:url('res/ncard-install-btn-1.png');}QPushButton:hover{border:0px;background-image:url('res/ncard-install-btn-2.png');}QPushButton:pressed{border:0px;background-image:url('res/ncard-install-btn-3.png');}")
+                    self.ui.btnDetail.setStyleSheet("QPushButton{border:0px;background-image:url('res/ncard-install-border.png');}")
+
+            #
+            # if self.app.percent < 0:
+            #     self.star.hide()
